@@ -1,6 +1,6 @@
 # ImVirt - I'm virtualized?
 #
-# $Id: kmods.pm 494 2010-03-04 20:55:45Z liske $
+# $Id: kmods.pm 544 2012-01-15 20:31:53Z liske $
 #
 # Authors:
 #   Thomas Liske <liske@ibh.de>
@@ -28,6 +28,7 @@ package ImVirt::Utils::kmods;
 
 use strict;
 use warnings;
+use Data::Dumper;
 use ImVirt::Utils::procfs;
 
 require Exporter;
@@ -54,6 +55,7 @@ while(<HKMS>) {
 	    ${$kmods{$1}}{'by'} = $6;
 	}
 }
+ImVirt::debug(__PACKAGE__, Dumper(\%kmods));
 
 sub kmods_get() {
     return %kmods;
@@ -65,7 +67,10 @@ sub kmods_match(%) {
 
     foreach my $kmod (keys %kmods) {
 	foreach my $regex (keys %regexs) {
-	    $pts += $regexs{$regex} if($kmod =~ /$regex/);
+	    if($kmod =~ /$regex/) {
+		$pts += $regexs{$regex};
+		delete($regexs{$regex});
+	    }
 	}
     }
 
