@@ -1,6 +1,6 @@
 # ImVirt - I'm virtualized?
 #
-# $Id: pcidevs.pm 522 2011-02-10 11:16:39Z liske $
+# $Id: pcidevs.pm 539 2011-08-19 13:06:47Z liske $
 #
 # Authors:
 #   Thomas Liske <liske@ibh.de>
@@ -28,6 +28,7 @@ package ImVirt::Utils::pcidevs;
 
 use strict;
 use warnings;
+use Data::Dumper;
 use IO::Handle;
 require Exporter;
 our @ISA = qw(Exporter);
@@ -69,6 +70,7 @@ if(my $pid = fork()) {
 
     exit;
 }
+ImVirt::debug(__PACKAGE__, Dumper(\%pcidevs));
 
 sub pcidevs_get() {
     return %pcidevs;
