@@ -1,6 +1,6 @@
 # ImVirt - I'm virtualized?
 #
-# $Id: KVM.pm 534 2011-06-02 19:38:13Z liske $
+# $Id: KVM.pm 543 2012-01-15 20:26:52Z liske $
 #
 # Authors:
 #   Thomas Liske <liske@ibh.de>
@@ -51,7 +51,7 @@ sub detect($) {
 
     # Check dmidecode
     if(defined(my $spn = dmidecode_string('system-product-name'))) {
-        if ($spn =~ /^KVM/) {
+        if ($spn =~ /^(KVM|Bochs)/) {
             ImVirt::inc_pts($dref, IMV_PTS_MAJOR, IMV_VIRTUAL, PRODUCT);
         }
         else {
@@ -59,7 +59,7 @@ sub detect($) {
         }
     }
     if(defined(my $spn = dmidecode_string('bios-vendor'))) {
-        if ($spn =~ /^QEMU/) {
+        if ($spn =~ /^(QEMU|Bochs)/) {
             ImVirt::inc_pts($dref, IMV_PTS_MAJOR, IMV_VIRTUAL, PRODUCT);
         }
         else {
